@@ -145,14 +145,13 @@ def append(append_service, verbose):  # Ajoute un service a la liste et l'ajoute
     if str(exist_service).find(".service"):
         print("Service exist \nSaving ...")
 
-        service_to_append = append_service
-
         print(f"Opening the file {file_ini_service}")
         backup_file = open(file_ini_service, "wb")
 
-        print(f"Appending the service {append_service}")
-        pickle.dump(service_to_append, backup_file)
+        print(f"Appending the service {service_to_append}")
+        pickle.dump(append_service, backup_file)
         backup_file.close()
+        service_check.append(append_service)
         print("Saved !")
     else:
         print("Service don't exist")
@@ -176,7 +175,7 @@ def check_service(verbose):
 
 
 def service_down(service, verbose):
-    global active
+    global active, number_restart
     if verbose:
         enablePrint()
 
@@ -209,20 +208,26 @@ def send_mail(subject, verbose):
 
     # Envoie un mail
     now = datetime.datetime.now()
+    cpu_temp = "paste <(cat /sys/class/thermal/thermal_zone*/temp) | column -s $ -t | sed 's/\(.\)..$/°C/'"
+    cpu_usage = """awk '{u=$2+$4; t=$2+$4+$5; if (NR==1){u1=u; t1=t;} else print ($2+$4-u1) * 100 / (t-t1) "%"; }' <(
+    grep 'cpu ' /proc/stat) <(sleep 1;grep 'cpu ' /proc/stat)"""
+
     message = f"""\
-        Subject: Oh non le service {subject} à planté !
+    Subject: Oh non le service {subject} à planté !
 
-        Bonjour, Je tiens à vous informer que ce jour le {now.day}/{now.month}/{now.year} à {now.hour}:{now.minute} le 
-        service intitulé {subject} à planté avec ceci en log : '{os.popen(f"systemctl status {subject}")}'.
-        Plusieurs operation affin de le relancer ont toutes échouées
-        From Auto_Check_service Python Bot"""
+    Bonjour, Je tiens à vous informer que ce jour le {now.day}/{now.month}/{now.year} à {now.hour}:{now.minute} le 
+    service intitulé {subject} à planté.
+    {number_restart} operation affin de le relancer ont toutes échouées
+    
+    Information système : 
+    CPU Temp = {os.popen(cpu_temp).read()}
+    CPU Usage = {os.popen(cpu_usage).read()}
+    From Auto_Check_service Python Bot"""
 
-    context = ssl.create_default_context()
-    print("Sending mail...")
     try:
+        context = ssl.create_default_context()
         with smtplib.SMTP_SSL(smtp_server, email_smtp_port, context=context) as server:
             server.login(sender_email, email_password)
-
             server.sendmail(sender_email, receiver_email, message.encode("utf8"))
 
             print("Successful sending mail")
@@ -334,7 +339,7 @@ def init():
 
     print(f"Verification of the packages make sure that no task are active with the {BOLD}APT{ENDC} command ...")
     try:
-        os.system("sudo apt install -y systemd")
+        os.system("sudo apt install -y systemd sysstat")
         print("Verification and installation completed.")
     except:
         print("Installation failed retry another time with the command 'sudo apt install -y systemd'.")
